==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/integration/tracing/tracing-opentracing/src/main/java/org/apache/cxf/tracing/opentracing/jaxrs/OpenTracingFeature.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.tracing.opentracing.jaxrs;

import javax.ws.rs.core.Feature;
import javax.ws.rs.core.FeatureContext;
import javax.ws.rs.ext.Provider;

import io.opentracing.Tracer;
import io.opentracing.util.GlobalTracer;

@Provider
public class OpenTracingFeature implements Feature {
    private final Tracer tracer;

    public OpenTracingFeature() {
        this(GlobalTracer.get());
    }

    public OpenTracingFeature(final Tracer tracer) {
        this.tracer = tracer;
    }

    @Override
    public boolean configure(FeatureContext context) {
        context.register(new OpenTracingProvider(tracer));
        context.register(new OpenTracingContextProvider(tracer));
        return true;
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/integration/tracing/tracing-opentracing/src/main/java/org/apache/cxf/tracing/opentracing/jaxrs/OpenTracingFeature.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.tracing.opentracing.jaxrs;

import jakarta.ws.rs.core.Feature;
import jakarta.ws.rs.core.FeatureContext;
import jakarta.ws.rs.ext.Provider;

import io.opentracing.Tracer;
import io.opentracing.util.GlobalTracer;

@Provider
public class OpenTracingFeature implements Feature {
    private final Tracer tracer;

    public OpenTracingFeature() {
        this(GlobalTracer.get());
    }

    public OpenTracingFeature(final Tracer tracer) {
        this.tracer = tracer;
    }

    @Override
    public boolean configure(FeatureContext context) {
        context.register(new OpenTracingProvider(tracer));
        context.register(new OpenTracingContextProvider(tracer));
        return true;
    }
}
